@@ -1,13 +1,12 @@
 package XML::NewsML_G2::Provider;
 
-# $Id: Provider.pm 55790 2014-08-26 18:30:30Z apatecgortan $
+# $Id: Provider.pm 57298 2014-10-21 15:03:54Z apatecgortan $
 
 use Moose;
 use namespace::autoclean;
 
 with 'XML::NewsML_G2::Role::HasQCode';
 
-has 'notice', isa => 'Str', is => 'ro';
 
 __PACKAGE__->meta->make_immutable;
 
@@ -22,16 +21,6 @@ XML::NewsML_G2::Provider - the news provider (news agency)
 
     my $apa = XML::NewsML_G2::Provider->new(name => 'APA', qcode => 'apa');
 
-=head1 ATTRIBUTES
-
-=over 4
-
-=item notice
-
-for an optional copyright notice
-
-=back
-
 =head1 AUTHOR
 
 Philipp Gortan  C<< <philipp.gortan@apa.at> >>
